@@ -270,6 +270,13 @@ uninstall_zypper() {
 }
 
 install_deb() {
+    if [ -f /etc/default/ubnt-dpkg-cache ]; then
+        # On UnifiOS 2, make sure the package is persisted over upgrades
+        sed -e '/^DPKG_CACHE_UBNT_PKGS+=" nextdns"/{:a;n;ba;q}' \
+            -e '$aDPKG_CACHE_UBNT_PKGS+=" nextdns"' \
+            -i /etc/default/ubnt-dpkg-cache
+    fi
+
     # Fallback on curl, some debian based distrib don't have wget while debian
     # doesn't have curl by default.
     ( asroot wget -qO /usr/share/keyrings/nextdns.gpg https://repo.nextdns.io/nextdns.gpg ||
@@ -456,8 +463,8 @@ uninstall_opnsense() {
 }
 
 ubios_install_source() {
-    echo "deb [signed-by=/usr/share/keyrings/nextdns.gpg] https://repo.nextdns.io/deb stable main" > /tmp/nextdns.list
-    podman cp /tmp/nextdns.list unifi-os:/etc/apt/sources.list.d/nextdns.list
+    echo "deb [signed-by=/usr/share/keyrings/nextdns.gpg] https://repo.nextdns.io/deb stable main" > /data/nextdns.list
+    podman exec unifi-os mv /data/nextdns.list /etc/apt/sources.list.d/nextdns.list
     rm -f /tmp/nextdns.list
     podman exec unifi-os apt-get install -y gnupg1 curl
     podman exec unifi-os curl -sfL https://repo.nextdns.io/nextdns.gpg -o /usr/share/keyrings/nextdns.gpg
@@ -513,7 +520,7 @@ install_type() {
     opensuse-tumbleweed|opensuse-leap|opensuse)
         echo "zypper"
         ;;
-    debian|ubuntu|elementary|raspbian|linuxmint|pop|neon|sparky|vyos)
+    debian|ubuntu|elementary|raspbian|linuxmint|pop|neon|sparky|vyos|Deepin)
         echo "deb"
         ;;
     alpine)
@@ -882,7 +889,7 @@ detect_os() {
                 fi
                 echo "$dist"; return 0
                 ;;
-            debian|ubuntu|elementary|raspbian|centos|fedora|rhel|arch|manjaro|openwrt|clear-linux-os|linuxmint|opensuse-tumbleweed|opensuse-leap|opensuse|solus|pop|neon|overthebox|sparky|vyos|void|alpine)
+            debian|ubuntu|elementary|raspbian|centos|fedora|rhel|arch|manjaro|openwrt|clear-linux-os|linuxmint|opensuse-tumbleweed|opensuse-leap|opensuse|solus|pop|neon|overthebox|sparky|vyos|void|alpine|Deepin)
                 echo "$dist"; return 0
                 ;;
             esac
@@ -980,14 +987,17 @@ silent_exec() {
 
 bin_location() {
     case $OS in
-    centos|fedora|rhel|debian|ubuntu|elementary|raspbian|arch|manjaro|clear-linux-os|linuxmint|opensuse-tumbleweed|opensuse-leap|opensuse|solus|pop|neon|sparky|vyos|void|alpine)
+    centos|fedora|rhel|debian|ubuntu|elementary|raspbian|arch|manjaro|clear-linux-os|linuxmint|opensuse-tumbleweed|opensuse-leap|opensuse|solus|pop|neon|sparky|vyos|void|alpine|Deepin)
         echo "/usr/bin/nextdns"
         ;;
     openwrt|overthebox)
         echo "/usr/sbin/nextdns"
         ;;
-    darwin|synology)
+    synology)
         echo "/usr/local/bin/nextdns"
+	;;
+    darwin)
+	echo "$(brew --prefix 2>/dev/null || echo /usr/local)/bin/nextdns"
         ;;
     asuswrt-merlin|ddwrt)
         echo "/jffs/nextdns/nextdns"
@@ -1089,4 +1099,5 @@ openssl_get() {
         openssl s_client -quiet -connect "$host:443" 2>/dev/null
 }
 
+umask 0022
 main
